@@ -984,7 +984,7 @@ att_estimate_defense(combat_mode, off, olist, def, a_spy)
 		return ototal;
 	pr("\n             Initial attack strength: %8d\n", ototal);
 
-	estimate = round(def->troops, 10);
+	estimate = att_combat_eff(def) * round(def->troops, 10);
 	estimate += att_combat_eff(def) * get_dlist(def, 0, a_spy, 0);
 
 	/*
